# etcd3 gateway Python Client

[![Build Status](https://travis-ci.org/dims/etcd3-gateway.svg?branch=master)](https://travis-ci.org/dims/etcd3-gateway)
[![PyPI version](https://badge.fury.io/py/etcd3gw.svg)](https://badge.fury.io/py/etcd3gw)
[![codecov](https://codecov.io/gh/dims/etcd3-gateway/branch/master/graph/badge.svg)](https://codecov.io/gh/dims/etcd3-gateway "Non-generated packages only")
[![pypi status](https://img.shields.io/pypi/status/etcd3gw.svg)](https://pypi.python.org/pypi/etcd3gw)
[![pypi supported versions](https://img.shields.io/pypi/pyversions/etcd3gw.svg)](https://pypi.python.org/pypi/etcd3gw)

A python client for etcd3 grpc-gateway v3alpha API